@@ -15,7 +15,7 @@
 
 There should be a file 'ftesting.zcml' in the current directory.
 
-$Id: functional.py 90093 2008-08-21 20:35:37Z fdrake $
+$Id: functional.py 110210 2010-03-26 17:01:02Z mgedmin $
 """
 import logging
 import os.path
@@ -24,6 +24,7 @@ import rfc822
 import sys
 import traceback
 import unittest
+import doctest
 from StringIO import StringIO
 from Cookie import SimpleCookie
 from transaction import abort, commit
@@ -36,7 +37,6 @@ from zope.publisher.browser import BrowserRequest, setDefaultSkin
 from zope.publisher.http import HTTPRequest
 from zope.publisher.publish import publish
 from zope.security.interfaces import Forbidden, Unauthorized
-from zope.testing import doctest
 
 import zope.app.testing.setup
 from zope.app.appsetup.appsetup import multi_database
