@@ -13,14 +13,14 @@
 ##############################################################################
 """Test tcpdoc
 
-$Id: tests.py 90088 2008-08-21 18:19:38Z fdrake $
+$Id: tests.py 110210 2010-03-26 17:01:02Z mgedmin $
 """
 import os
 import re
 import unittest
 import StringIO
+from doctest import DocTestSuite
 
-from zope.testing.doctestunit import DocTestSuite
 from zope.testing.renormalizing import RENormalizing
 from zope.component import getAllUtilitiesRegisteredFor
 from ZODB.interfaces import IDatabase
